# PR2 IKFast Python Bindings
cpp codes are fetched from https://github.com/caelan/pybullet-planning (MIT License), where the cpp code themselves (Apache License 2.0) are generated by IKFast. This repo just provides simple `pip installable` python package using setuptools.

## Installation
```bash
pip install .
```

## Usage
```python
import numpy as np
from pr2_ikfast import solve_left_ik, solve_right_ik

trans = [0.5, -0.2, 0.8]
rot   = np.eye(3).tolist()
free  = [0.1, 0.2]

sol_left  = solve_left_ik(trans, rot, free)
sol_right = solve_right_ik(trans, rot, free)
```
